==> apache-servicecomb-java-chassis-distribution-2.0.0-src.zip: apache-servicecomb-java-chassis-distribution-2.0.0-src/core/src/main/java/org/apache/servicecomb/core/definition/ConsumerMicroserviceVersionsMeta.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.core.definition;

import org.apache.servicecomb.core.SCBEngine;
import org.apache.servicecomb.core.provider.consumer.MicroserviceReferenceConfig;
import org.apache.servicecomb.serviceregistry.consumer.MicroserviceVersions;

public class ConsumerMicroserviceVersionsMeta extends MicroserviceVersionsMeta {
  private MicroserviceVersions microserviceVersions;

  private MicroserviceReferenceConfig microserviceReferenceConfig;

  public ConsumerMicroserviceVersionsMeta(SCBEngine scbEngine, MicroserviceVersions microserviceVersions) {
    super(scbEngine, microserviceVersions.getMicroserviceName());

    this.microserviceVersions = microserviceVersions;
  }

  public MicroserviceVersions getMicroserviceVersions() {
    return microserviceVersions;
  }

  public MicroserviceReferenceConfig getOrCreateMicroserviceReferenceConfig() {
    if (microserviceReferenceConfig == null ||
        microserviceReferenceConfig.isExpired()) {
      microserviceReferenceConfig = new MicroserviceReferenceConfig(this, null);
    }

    return microserviceReferenceConfig;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/core/src/main/java/org/apache/servicecomb/core/definition/ConsumerMicroserviceVersionsMeta.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.core.definition;

import org.apache.servicecomb.core.SCBEngine;
import org.apache.servicecomb.core.provider.consumer.MicroserviceReferenceConfig;
import org.apache.servicecomb.registry.consumer.MicroserviceVersions;

public class ConsumerMicroserviceVersionsMeta extends MicroserviceVersionsMeta {
  private MicroserviceVersions microserviceVersions;

  private MicroserviceReferenceConfig microserviceReferenceConfig;

  public ConsumerMicroserviceVersionsMeta(SCBEngine scbEngine, MicroserviceVersions microserviceVersions) {
    super(scbEngine, microserviceVersions.getMicroserviceName());

    this.microserviceVersions = microserviceVersions;
  }

  public MicroserviceVersions getMicroserviceVersions() {
    return microserviceVersions;
  }

  public MicroserviceReferenceConfig getOrCreateMicroserviceReferenceConfig() {
    if (microserviceReferenceConfig == null ||
        microserviceReferenceConfig.isExpired()) {
      microserviceReferenceConfig = new MicroserviceReferenceConfig(this, null);
    }

    return microserviceReferenceConfig;
  }
}
